# Python Windows SDK

Python bindings for the Windows SDK.

This is a community-supported version of the unmaintained [winrt] package.

[winrt]: https://pypi.org/project/winrt


## Installation

This package is distributed on PyPI as the [winsdk] package.

    # use your favorite environment manager
    poetry add winsdk
    pipenv install winsdk
    pip install winsdk

[winsdk]: https://pypi.org/project/winsdk


## Documentation

https://python-winsdk.readthedocs.io/en/latest/
